==> claromentis-framework-9.6.6-26891208.zip: web/intranet/admin/classes/Sysadmin/NullProgressInterface.php <==
<?php
namespace Claromentis\Admin\Sysadmin;

$GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"] = (@$GLOBALS["__65da1b1ec2" . "d6653e8a0ab7" . "848e536215"] ?: array()) + array("_4d707fab93bebb00bbe69e8159697" . "c90" => base64_decode(""));
use Claromentis\Core\Lock\Exception\LockAcquisitionException;
class NullProgressInterface implements WritableExportProgressInterface
{
    public function GetId() : int
    {
        return 0;
    }
    public function GetUnexportedDataFiles() : array
    {
        return [];
    }
    public function GetUnexportedCdnFiles() : array
    {
        return [];
    }
    public function GetIncompleteTables() : array
    {
        return [];
    }
    public function IsDescriptionWritten() : bool
    {
        return true;
    }
    public function IsArchiveFinalised() : bool
    {
        return true;
    }
    public function ExportProgress() : float
    {
        return 1.0;
    }
    public function RegisterDataFiles(array $_00f2055c7cbd408ef56949f35c62b721) : void
    {
        
        
    }
    public function RegisterCdnFiles(array $_00f2055c7cbd408ef56949f35c62b721) : void
    {
        
        
    }
    public function RegisterTables(array $_08453d119db192b790995e6d610cb413) : void
    {
        
        
    }
    public function MarkDataFileDone(string $_82a65eef3d03e3f61aac05df4e052c1f) : void
    {
        
        
    }
    public function MarkCdnFileDone(string $_82a65eef3d03e3f61aac05df4e052c1f) : void
    {
        
        
    }
    
    
    
    
    
    public function LockTable(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function MarkTableProgress(string $_6555f4024e92c4a6b9140e99cd668e2b, int $_5f42d55f4c50c2ac2c3e7b1234a36729) : void
    {
        
        
    }
    public function MarkTableDone(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function ReleaseTable(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function MarkDescriptionDone() : void
    {
        
        
    }
    public function MarkArchiveFinalised() : void
    {
        
        
    }
    public function DateStarted() : string
    {
        return $GLOBALS["__65da1b1ec2d66" . "53e8a0ab7848e53" . "6215"]["_4d707fab93bebb00bbe69e" . "8159697c90"];
    }
    public function GetTablesSize()
    {
        return 0;
    }
    public function GetTablesProgress()
    {
        return 0;
    }
    public function GetDataSize()
    {
        return 0;
    }
    public function GetDataProgress()
    {
        return 0;
    }
    public function GetCdnSize()
    {
        return 0;
    }
    public function GetCdnProgress()
    {
        return 0;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/admin/classes/Sysadmin/NullProgressInterface.php <==
<?php
namespace Claromentis\Admin\Sysadmin;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] ?: array()) + array("_4d707fab93bebb00bbe69e815" . "9697c90" => base64_decode(""));
use Claromentis\Core\Lock\Exception\LockAcquisitionException;
class NullProgressInterface implements WritableExportProgressInterface
{
    public function GetId() : int
    {
        return 0;
    }
    public function GetUnexportedDataFiles() : array
    {
        return [];
    }
    public function GetUnexportedCdnFiles() : array
    {
        return [];
    }
    public function GetIncompleteTables() : array
    {
        return [];
    }
    public function IsDescriptionWritten() : bool
    {
        return true;
    }
    public function IsArchiveFinalised() : bool
    {
        return true;
    }
    public function ExportProgress() : float
    {
        return 1.0;
    }
    public function RegisterDataFiles(array $_00f2055c7cbd408ef56949f35c62b721) : void
    {
        
        
    }
    public function RegisterCdnFiles(array $_00f2055c7cbd408ef56949f35c62b721) : void
    {
        
        
    }
    public function RegisterTables(array $_08453d119db192b790995e6d610cb413) : void
    {
        
        
    }
    public function MarkDataFileDone(string $_82a65eef3d03e3f61aac05df4e052c1f) : void
    {
        
        
    }
    public function MarkCdnFileDone(string $_82a65eef3d03e3f61aac05df4e052c1f) : void
    {
        
        
    }
    
    
    
    
    
    public function LockTable(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function MarkTableProgress(string $_6555f4024e92c4a6b9140e99cd668e2b, int $_5f42d55f4c50c2ac2c3e7b1234a36729) : void
    {
        
        
    }
    public function MarkTableDone(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function ReleaseTable(string $_6555f4024e92c4a6b9140e99cd668e2b) : void
    {
        
        
    }
    public function MarkDescriptionDone() : void
    {
        
        
    }
    public function MarkArchiveFinalised() : void
    {
        
        
    }
    public function DateStarted() : string
    {
        return $GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"]["_4d707fab93bebb0" . "0bbe69e8159697c9" . "0"];
    }
    public function GetTablesSize()
    {
        return 0;
    }
    public function GetTablesProgress()
    {
        return 0;
    }
    public function GetDataSize()
    {
        return 0;
    }
    public function GetDataProgress()
    {
        return 0;
    }
    public function GetCdnSize()
    {
        return 0;
    }
    public function GetCdnProgress()
    {
        return 0;
    }
}
